==> openshift-serverless-logic-1.29.0-src.zip: openshift-serverless-logic-1.29.0.GA-src/org.kie.kogito-kogito-apps-1.38.0.Final/ui-packages/packages/forms-list/src/envelope/FormsListEnvelopeView.tsx <==
/*
 * Copyright 2021 Red Hat, Inc. and/or its affiliates.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

import React, { useImperativeHandle, useState } from 'react';
import { MessageBusClientApi } from '@kogito-tooling/envelope-bus/dist/api';
import { FormsListChannelApi } from '../api';
import FormsList from './components/FormsList/FormsList';
import FormsListEnvelopeViewDriver from './FormsListEnvelopeViewDriver';
import '@patternfly/patternfly/patternfly.css';

export interface FormsListEnvelopeViewApi {
  initialize: () => void;
}

interface Props {
  channelApi: MessageBusClientApi<FormsListChannelApi>;
}

export const FormsListEnvelopeView = React.forwardRef<
  FormsListEnvelopeViewApi,
  Props
>((props, forwardedRef) => {
  const [isEnvelopeConnectedToChannel, setEnvelopeConnectedToChannel] =
    useState<boolean>(false);
  useImperativeHandle(
    forwardedRef,
    () => ({
      initialize: () => {
        setEnvelopeConnectedToChannel(true);
      }
    }),
    []
  );

  return (
    <React.Fragment>
      <FormsList
        isEnvelopeConnectedToChannel={isEnvelopeConnectedToChannel}
        driver={new FormsListEnvelopeViewDriver(props.channelApi)}
      />
    </React.Fragment>
  );
});

export default FormsListEnvelopeView;

==> openshift-serverless-logic-1.31.0-src.zip: openshift-serverless-logic-1.31.0.GA-src/org.kie.kogito-kogito-apps-1.44.0.Final/ui-packages/packages/forms-list/src/envelope/FormsListEnvelopeView.tsx <==
/*
 * Copyright 2021 Red Hat, Inc. and/or its affiliates.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

import React, { useImperativeHandle, useState } from 'react';
import { MessageBusClientApi } from '@kie-tools-core/envelope-bus/dist/api';
import { FormsListChannelApi } from '../api';
import FormsList from './components/FormsList/FormsList';
import FormsListEnvelopeViewDriver from './FormsListEnvelopeViewDriver';
import '@patternfly/patternfly/patternfly.css';

export interface FormsListEnvelopeViewApi {
  initialize: () => void;
}

interface Props {
  channelApi: MessageBusClientApi<FormsListChannelApi>;
}

export const FormsListEnvelopeView = React.forwardRef<
  FormsListEnvelopeViewApi,
  Props
>((props, forwardedRef) => {
  const [isEnvelopeConnectedToChannel, setEnvelopeConnectedToChannel] =
    useState<boolean>(false);
  useImperativeHandle(
    forwardedRef,
    () => ({
      initialize: () => {
        setEnvelopeConnectedToChannel(true);
      }
    }),
    []
  );

  return (
    <React.Fragment>
      <FormsList
        isEnvelopeConnectedToChannel={isEnvelopeConnectedToChannel}
        driver={new FormsListEnvelopeViewDriver(props.channelApi)}
      />
    </React.Fragment>
  );
});

export default FormsListEnvelopeView;
